@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.0501';
+our $VERSION = '0.06';
 
 use warnings;
 use strict;
@@ -31,6 +31,13 @@ sub populate {
             $vertex++;
         }
     }
+    elsif ($data_ref eq 'Math::MatrixReal') {
+        my $vertex = 0;
+        for my $neighbors (@{ $data->[0] }) {
+            $self->_from_array( $vertex, $neighbors, $attr, $format );
+            $vertex++;
+        }
+    }
     elsif ($data_ref eq 'HASH') {
         for my $vertex (keys %$data) {
             if ( $data->{$vertex}{attributes} ) {
@@ -199,7 +206,7 @@ Graph::Easy::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.0501
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -261,7 +268,7 @@ as documented, but with the addition of custom weighting.
 
 =head2 new()
 
-  my $gw = Graph::Easy::Weighted->new;
+  $gw = Graph::Easy::Weighted->new;
 
 Return a new C<Graph::Easy::Weighted> object.
 
@@ -279,8 +286,8 @@ Please see L<Graph::Easy/new()> for the possible constructor arguments.
 
 Populate a graph with weighted nodes.
 
-The data can be an arrayref of numeric vectors, a C<Math::MatrixReal> object, or
-a hashref of numeric edge values.
+The data can be an arrayref of numeric vectors, a C<Math::Matrix> object, a
+C<Math::MatrixReal> object, or a hashref of numeric edge values.
 
 Data given as a hash reference may contain node attributes as shown in the
 SYNOPSIS.  See L<Graph::Easy::Manual> for the available attributes.
@@ -312,22 +319,22 @@ Return the weight or named attribute value for the vertex or edge.
 
 =head2 vertex_span()
 
- my ($lightest, $heaviest) = $gw->vertex_span();
- my ($lightest, $heaviest) = $gw->vertex_span($attr);
+ ($lightest, $heaviest) = $gw->vertex_span();
+ ($lightest, $heaviest) = $gw->vertex_span($attr);
 
 Return the lightest and heaviest vertices.
 
 =head2 edge_span()
 
- my ($lightest, $heaviest) = $gw->edge_span();
- my ($lightest, $heaviest) = $gw->edge_span($attr);
+ ($lightest, $heaviest) = $gw->edge_span();
+ ($lightest, $heaviest) = $gw->edge_span($attr);
 
 Return the lightest to heaviest edges.
 
 =head2 path_cost()
 
- my $weight = $gw->path_cost(\@named_vertices);
- my $weight = $gw->path_cost(\@named_vertices, $attr);
+ $c = $gw->path_cost(\@named_vertices);
+ $c = $gw->path_cost(\@named_vertices, $attr);
 
 Return the summed weight (or given cost attribute) of the path edges.
 
